﻿using Infragistics.Graphics;
using Infragistics.Portable.Components.Data;
using Infragistics.Win.DataVisualization;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UltraGeoMapPerformanceTest
{
    public partial class Form1 : Form
    {
        Random r = new Random();
        public Form1()
        {
            InitializeComponent();

            ultraGeographicMap1.Zoomable = true;

            this.PlotPointTest();
        }

        private void PlotPointTest()
        {
            List<LatitudeLongitude> points = new List<LatitudeLongitude>();
            for (int i = 0; i < 1; i++)
            {
                points.Add(new LatitudeLongitude() { DoubleLongitude = r.Next(-108, -66), DoubleLatitude = r.Next(45, 50) });
            }

            this.PlotPoints(points);
        }

        public void PlotPoints(List<LatitudeLongitude> points, bool centerOn = false, double scaleFactor = 0.01)
        {
            //var template = new CustomRenderTemplate();
            //template.Render = new DataTemplateRenderHandler(templateRenderHandler);

            var series = new GeographicSymbolSeries()
            {
                LongitudeMemberPath = "X",
                LatitudeMemberPath = "Y",
                //MarkerTemplate = template
            };

            var brush = new Infragistics.Win.DataVisualization.SolidColorBrush();
            brush.Color = System.Drawing.Color.WhiteSmoke;
            series.Brush = brush;
            series.MarkerBrush = brush;

            var outline = new Infragistics.Win.DataVisualization.SolidColorBrush();
            outline.Color = System.Drawing.Color.FromArgb(21, 115, 255);
            series.MarkerOutline = outline;

            series.IsHighlightingEnabled = true;

            series.MouseOverEnabled = true;
            series.Thickness = 0.5;

            var geoLocations = new List<Infragistics.Win.DataVisualization.Point>();

            foreach (var point in points)
            {
                var infraPoint = new Infragistics.Win.DataVisualization.Point() { X = point.DoubleLongitude, Y = point.DoubleLatitude };
                geoLocations.Add(infraPoint);
                this.CentreOnPoint(point.DoubleLongitude, point.DoubleLatitude);
            }

            series.DataSource = geoLocations;
            this.ultraGeographicMap1.Series.Add(series);


            // if only one point passed in, center on the given position - not sure if this is correct - should probably be in own method?
            //if (centerOn && points.Count == 1)
            //{
            //    .CenterOnPoint(points.First().DoubleLongitude, points.First().DoubleLatitude, scaleFactor);
            //}
        }

        public void CentreOnPoint(double longitude, double latitude, double scaleFactor = 0.001)
        {
            var southEastPoint = new Infragistics.Win.DataVisualization.Point(longitude + scaleFactor, latitude - scaleFactor);
            var northWestPoint = new Infragistics.Win.DataVisualization.Point(longitude - scaleFactor, latitude + scaleFactor);

            // use the GetZoomFromGeographic method to generate a new WindowRect
            var rect = this.ultraGeographicMap1.GetZoomFromGeographic(northWestPoint, southEastPoint);

            this.ultraGeographicMap1.WindowRect = rect;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            PlotPointTest();
        }
    }

    public class LatitudeLongitude
    {
        public double DoubleLongitude { get; set; }
        public double DoubleLatitude { get; set; }
    }

}
